.. _documentation-label:

==================
Package references
==================


Histogramming functions
-----------------------

.. automodule:: plothist.histogramming
   :members:

Plotting functions
------------------

.. automodule:: plothist.plotters
   :members:

Comparison functions
--------------------

.. automodule:: plothist.comparison
   :members:

Variable registry functions
---------------------------

.. automodule:: plothist.variable_registry
   :members:

Plotting style functions
------------------------

.. automodule:: plothist.plothist_style
   :members:
